@@ -1,5 +1,6 @@
 import socket
-from CGPCLI.Errors import FailedLogin, ConnectionTimeOut
+from CGPCLI.Parser import parse_to_python_object, parse_to_CGP_object
+from CGPCLI.Errors import FailedLogin, ConnectionTimeOut, CommandFailedError
 
 class CGPConnector:
     def __init__(self, host, port=106):
